.. Places parent toc into the sidebar

:parenttoc: True

.. title:: User guide: contents

.. _user_guide:

==========
User Guide
==========

.. toctree::
   :numbered:
   :maxdepth: 3

   modules/supervised_tree
   modules/unsupervised_tree
   modules/ensemble
